/vpcs/{uuid}/reload — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /vpcs/{uuid}/reload

Contents

- /vpcs/{uuid}/reload
  - POST /vpcs/{uuid}/reload
    - Parameters
    - Response status codes

## POST /vpcs/{uuid}/reload

Reload a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 400: Invalid instance UUID
- 404: Instance doesn’t exist
- 204: Instance reloaded

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »